#ifndef _TARTFOCALPLANE_H_
#define _TARTFOCALPLANE_H_

#include <TObjArray.h>
#include <TVectorD.h>

class TArtBigRIPSParameters;
class TArtPPACArray;
class TArtPlasticArray;
class TArtFocalPlanePara;

class TArtFocalPlaneArray : public TObjArray {

 public:
  TArtFocalPlaneArray() :loadppacmap(false), loadplmap(false) {}
  TArtFocalPlaneArray(TArtBigRIPSParameters *para) :loadppacmap(false), loadplmap(false)
      {LoadSetup(para);}
  virtual ~TArtFocalPlaneArray(){}

  virtual void LoadSetup(TArtBigRIPSParameters *para);
  virtual void LoadPPACMap(TArtPPACArray *ppac_array);
  virtual void LoadPlasticMap(TArtPlasticArray *pla_array);
  virtual void ClearData();
  virtual void RecoBeamPos(); // reconstruct x,y angle and position
  virtual Bool_t IsPPACMapLoaded(){return loadppacmap;}
  virtual Bool_t IsPlasticMapLoaded(){return loadplmap;}

 private:
  Bool_t loadppacmap;
  Bool_t loadplmap;

  ClassDef(TArtFocalPlaneArray,1);

};

class TArtFocalPlane : public TNamed {

 public: 

  TArtFocalPlane(TArtFocalPlanePara *para);
  virtual ~TArtFocalPlane();

  virtual void RecoBeamPos();
  virtual void ClearData();
  virtual Int_t GetFpl();
  virtual Double_t GetZpos();
  virtual TVectorD * GetOptVector(){return &opt_vector;}
  virtual void LoadPPACMap(TArtPPACArray *ppacs);
  virtual void LoadPlasticMap(TArtPlasticArray *plas);

  // calibration parameter
  virtual Int_t GetID();

 private:

  // optical vector measured with near PPAC detector
  // 0: x position
  // 1: a angle
  // 2: y position
  // 3: b angle
  // 4: delta
  TVectorD opt_vector;

  // num-xppac fired
  double nfired_ppacx;

  // num-yppac fired
  double nfired_ppacy;

  // setup
  TArtFocalPlanePara * para;
  TArtPPACArray * ppac_array; // array of the pointer to the corresponding ppac
  TArtPlasticArray * pla_array; // array of the pointer to the corresponding plastic

  ClassDef(TArtFocalPlane,1);

};

#endif
