#ifndef _TARTIC_H_
#define _TARTIC_H_

#include <TObjArray.h>
#include "TArtCalibPID.h"

class TArtBigRIPSParameters;
class TArtICPara;
class TArtMapper;

#define NUM_IC_CHANNEL 8

class TArtICArray : public TObjArray {

 public:
  TArtICArray() {}
  TArtICArray(TArtBigRIPSParameters *para) {LoadSetup(para);}
  virtual ~TArtICArray(){}

  virtual void LoadSetup(TArtBigRIPSParameters *para);
  virtual void LoadRawDataMap(TArtMapper *mapper);
  virtual void ClearData();
  virtual void ReconstructData(); // raw value -> physics value

  ClassDef(TArtICArray,1);

};

class TArtIC : public TNamed {

 public:
  TArtIC(TArtICPara *p);
  virtual ~TArtIC();

  void LoadRawDataMap(TArtMapper *mapper);
  void ClearData();
  void ReconstructData(); // raw value -> physics value
  bool IsReconstructed(){ return fReconstructed; }

  // function to set raw data
  void SetRawData(int ch, int val){fChEnergyRaw[ch] = val;}
  unsigned int GetRawData(int ch){return fChEnergyRaw[ch];}

  bool  IsFired()         {return fFired;};
  double GetCalMeVSqSum()  {return fCalMeVSqSum;}
  double GetCalMeVAvSum()  {return fCalMeVAvSum;}

  double RecoZet(double beta);

  // calibration parameter
  Int_t        GetID();
  Int_t        GetFpl();
  TString    * GetDetectorName();
  TArtICPara * GetParameter(){return para;}

 private:

  unsigned int fChEnergyRaw[NUM_IC_CHANNEL];

  bool    fFired;             // flag to Check if the IC is ok  
  double  fCalMeVSqSum;
  double  fCalMeVAvSum;

  bool    fReconstructed;

  TArtICPara * para;

  ClassDef(TArtIC,1);

};
#endif
